<?php
/**
 * Greenturtle Mag functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Greenturtle_Mag
 */

if ( ! function_exists( 'greenturtle_mag_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function greenturtle_mag_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Greenturtle Mag, use a find and replace
		 * to change 'greenturtle-mag' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'greenturtle-mag', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		register_nav_menus( array(
		'primary-menu' => esc_html__( 'Primary', 'greenturtle-mag' ),
		'top-menu' => esc_html__( 'Top Menu', 'greenturtle-mag' ),
		'footer-menu' => esc_html__( 'Footer', 'greenturtle-mag' )
		) );

		
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'greenturtle_mag_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// Greenturtle Mag Thumbnail Sizes
		add_image_size( 'greenturtle-mag-slider-thumb', 554, 321, true );
		add_image_size( 'greenturtle-mag-highlight-thumb', 277, 163, true );
		add_image_size( 'greenturtle-mag-feature-thumb', 350, 203, true );
		add_image_size( 'greenturtle-mag-feature2-thumb', 558, 318, true );
		add_image_size( 'greenturtle-mag-feature3-thumb', 731, 417, true );
	
	}
endif;
add_action( 'after_setup_theme', 'greenturtle_mag_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function greenturtle_mag_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'greenturtle_mag_content_width', 640 );
}
add_action( 'after_setup_theme', 'greenturtle_mag_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function greenturtle_mag_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'greenturtle-mag' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'greenturtle-mag' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	  register_sidebar( array(
		'name'          => esc_html__( 'Home Page Main Highlight ', 'greenturtle-mag' ),
		'id'            => 'sidebar-front-highlight',
		'description'   => esc_html__( 'Add GTL Main Highlight Widgets Here.', 'greenturtle-mag' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );

	
	  register_sidebar( array(
		'name'          => esc_html__( 'Home Page Secodary ', 'greenturtle-mag' ),
		'id'            => 'sidebar-front-secondary',
		'description'   => esc_html__( 'Add Home Page Secodary Widgets Here.', 'greenturtle-mag' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );
	   register_sidebar( array(
		'name'          => esc_html__( 'Home Page Sidebar', 'greenturtle-mag' ),
		'id'            => 'sidebar-front-sidebar',
		'description'   => esc_html__( 'Add Home Page Sidebar Widgets Here.', 'greenturtle-mag' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	   

	

	register_sidebar( array(
		'name'          => esc_html__( 'Header Advertisement Widget Area', 'greenturtle-mag' ),
		'id'            => 'sidebar-top',
		'description'   => esc_html__( 'Add Advertisement Here.(Note: Image widget with 728*90 recommended)', 'greenturtle-mag' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );

     register_sidebar(array(
        'name' => __('Footer ', 'greenturtle-mag'),
        'id' => 'footer-sidebar',
        'description' => __('Displays items on footer section.','greenturtle-mag'),
        'before_widget' => '<div class="contact-list col-md-3 col-sm-3 col-xs-12"><aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside></div>',
        'before_title'  => '<h1 class="widget-title">',
        'after_title'   => '</h1>',
    ));

   
}
add_action( 'widgets_init', 'greenturtle_mag_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function greenturtle_mag_scripts() {
	
	wp_enqueue_style( 'greenturtle-mag-style', get_stylesheet_uri() );

	 wp_enqueue_style( 'greenturtle-mag-responsive', get_template_directory_uri() . '/css/responsive.css', array(), '3.4.0' );

	wp_enqueue_style( 'greenturtle-mag-google-fonts', 'https://fonts.googleapis.com/css?family=Roboto%7CRoboto%7CRoboto&amp;ver=4.8.2' );

	

	wp_enqueue_script( 'greenturtle-mag-jquery-modernizr', get_template_directory_uri() . '/js/modernizr.js', array('jquery'), '2.8.3', true );		
	
	wp_enqueue_script('greenturtle-mag-jquery-easing', get_template_directory_uri() . '/js/jquery.easing.js', array('jquery'), '0.3.6', 1);
	
    wp_enqueue_script('greenturtle-mag-jquery-waypoints', get_template_directory_uri() . '/js/jquery.waypoints.js', array('jquery'), '4.0.0', 1);

	wp_enqueue_script( 'greenturtle-mag-jquery-cycle-script', get_template_directory_uri() . '/js/jquery.cycle.js', array( 'jquery' ), '2.1.6', true );
	
	wp_enqueue_script('greenturtle-mag-custom-js', get_template_directory_uri() . '/js/greenturtle-mag-custom.js', array('jquery'), '', true);


	wp_enqueue_script( 'greenturtle-mag-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'greenturtle-mag-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if(esc_attr(get_theme_mod('gtlmag_font_setting'))):
	// Google Fonts
	wp_enqueue_style( 'greenturtle-mag-google-fonts-secondary','https://fonts.googleapis.com/css?family='. esc_attr(get_theme_mod('gtlmag_font_setting')).'' );
    endif; 
}
add_action( 'wp_enqueue_scripts', 'greenturtle_mag_scripts' );

function greenturtle_mag_admin_styles($hook) {
	if($hook == 'widgets.php'){
    wp_enqueue_style( 'greenturtle-mag-admin-style', get_template_directory_uri() . '/css/admin-style.css', array(), '1.0.0' );
    wp_enqueue_script( 'greenturtle-mag-image-uploader', get_template_directory_uri() . '/js/image-uploader.js', array(), '20151215', true );
}
}
add_action( 'admin_enqueue_scripts', 'greenturtle_mag_admin_styles' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';


/**
 * Load Hooks.
 */
require get_template_directory() . '/inc/hooks.php';

/**
 * Load Hooks.
 */
require get_template_directory() . '/inc/filters.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load Widgets
 */
require get_template_directory() . '/inc/widgets/main-highlights.php';



require get_template_directory() . '/inc/widgets/feature.php';

require get_template_directory() . '/inc/widgets/feature-two.php';


require get_template_directory() . '/inc/widgets/recent-posts.php';



require get_template_directory() . '/inc/widgets/advertisement.php';

require get_template_directory() . '/inc/widgets/tab-posts.php';
